@@ -11,7 +11,7 @@ use List::MoreUtils qw(first_index);
 use Readonly;
 Readonly my $INDEX_NOT_FOUND => -1;
 
-use version 0.9917; our $VERSION = version->declare('v2.6.1');
+use version 0.9917; our $VERSION = version->declare('v2.7.0');
 
 
 sub new {
@@ -119,6 +119,17 @@ sub getCommand {
 }
 
 
+sub getCommandPlain {
+    my $self = shift;
+    my $str  = q{};
+    foreach my $key ( sort keys %{ $self->{command} } ) {
+        my $val = $self->{command}->{$key};
+        $str .= "${key} = ${val}\n";
+    }
+    return $str;
+}
+
+
 sub getCurrentPageNumber {
     my $self  = shift;
     my $first = $self->getFirstRecordIndex();
@@ -451,6 +462,12 @@ Get the command used within the request that resulted in this api response.
 This is in general the command you provided in the constructor.
 Returns a hash.
 
+=item C<getCommandPlain>
+
+Get the command in plain text that you used within the API request of this response.
+This is in general the command you provided in the constructor.
+Returns a string.
+
 =item C<getCurrentPageNumber>
 
 Returns the current page number we are in with this API response as int.
